@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -676,6 +679,11 @@ if {$CLI_OPTION(check_libraries)} {
 		set library [lindex $::LIBRARIES_TO_LOAD [list $i 0]]	;# Library name
 		set version [lindex $::LIBRARIES_TO_LOAD [list $i 1]]	;# Library version
 
+		# Skip optional libraries.
+		if {[lsearch $::OPTIONAL_LIBRARIES $library] != -1} {
+			continue
+		}
+
 		# Print what library is currently being checked
 		if {$CLI_OPTION(nocolor)} {
 			puts "\t\t[expr {$i + 1}]/$librariesToCheck Checking for library $library"
