@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -77,6 +80,7 @@ namespace eval compiler {
 
 	variable primary_tab_asm	;# Widget: Tab "Assembly language"
 	variable primary_tab_c		;# Widget: Tab "C language"
+	variable primary_tab_make {}	;# Widget: Tab "MAIN/GNU make"
 	variable assembler_tab_compiler	;# Widget: Tab "Compiler"
 	variable assembler_tab_M8I	;# Widget: Tab "MCU8051IDE"
 	variable assembler_tab_ASEM51	;# Widget: Tab "ASEM-51"
