@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -32,8 +35,8 @@ set _SETTINGS_TCL _
 # --------------------------------------------------------------------------
 
 class Settings {
-	common dir_sep	[file separator]	;# Directory separator (eg. '/')
-	common settings_count		0	;# Counter of instances
+	public common dir_sep	[file separator]	;# Directory separator (eg. '/')
+	public common settings_count		0	;# Counter of instances
 
 	private variable isEmpty	1	;# Is settings array empty
 	private variable isReady	0	;# Is interface ready
