@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -33,16 +36,16 @@ set _VIRTUAL_HW_COMPONENT_TCL _
 # --------------------------------------------------------------------------
 
 class VirtualHWComponent {
-	common count		0	;# Int: Counter of object instances
-	common hlp_dlg_count	0	;# Int: Counter of help dialog instances
+	public common count		0	;# Int: Counter of object instances
+	public common hlp_dlg_count	0	;# Int: Counter of help dialog instances
 
 	# Create fonts used in the text
-	common hlp_normal_font [font create			\
+	public common hlp_normal_font [font create			\
 		-family {helvetica}				\
 		-size [expr {int(-14 * $::font_size_factor)}]	\
 		-weight {normal}				\
 	]
-	common hlp_bold_font [font create			\
+	public common hlp_bold_font [font create			\
 		-family {helvetica}				\
 		-size [expr {int(-14 * $::font_size_factor)}]	\
 		-weight {bold}					\
