@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -33,17 +36,17 @@ set _NOTES_TCL _
 
 class Notes {
 	## COMMON
-	common count	0			;# Int: Counter of object instances
-	common bgcolor	{#EEEE55}		;# Color: Background color for title bar and window border
-	common bgcolor2	{#FFFF88}		;# Color: Background color for the canvas widget
+	public common count	0			;# Int: Counter of object instances
+	public common bgcolor	{#EEEE55}		;# Color: Background color for title bar and window border
+	public common bgcolor2	{#FFFF88}		;# Color: Background color for the canvas widget
 	# Font: For inserted text
-	common canvas_text_font [font create			\
+	public common canvas_text_font [font create			\
 		-family $::DEFAULT_FIXED_FONT			\
 		-size [expr {int(-14 * $::font_size_factor)}]	\
 		-weight bold					\
 	]
 	# List: Popup menu for the canvas widget
-	common MENU {
+	public common MENU {
 		{radiobutton	"Pencil"	{}	::Notes::__mode		{P}
 			"change_mode P"		0}
 		{radiobutton	"Line"		{}	::Notes::__mode		{L}
